@@ -8,8 +8,10 @@ from playhouse.cockroachdb import CockroachDatabase
 from playhouse.cockroachdb import PooledCockroachDatabase
 from playhouse.pool import PooledMySQLDatabase
 from playhouse.pool import PooledPostgresqlDatabase
+from playhouse.pool import PooledPsycopg3Database
 from playhouse.pool import PooledSqliteDatabase
 from playhouse.pool import PooledSqliteExtDatabase
+from playhouse.psycopg3_ext import Psycopg3Database
 from playhouse.sqlite_ext import SqliteExtDatabase
 
 
@@ -24,6 +26,8 @@ schemes = {
     'postgresql': PostgresqlDatabase,
     'postgres+pool': PooledPostgresqlDatabase,
     'postgresql+pool': PooledPostgresqlDatabase,
+    'psycopg3': Psycopg3Database,
+    'psycopg3+pool': PooledPsycopg3Database,
     'sqlite': SqliteDatabase,
     'sqliteext': SqliteExtDatabase,
     'sqlite+pool': PooledSqliteDatabase,
@@ -39,13 +43,10 @@ def parseresult_to_dict(parsed, unquote_password=False):
 
     # urlparse in python 2.6 is broken so query will be empty and instead
     # appended to path complete with '?'
-    path_parts = parsed.path[1:].split('?')
-    try:
-        query = path_parts[1]
-    except IndexError:
-        query = parsed.query
+    path = parsed.path[1:]  # Ignore leading '/'.
+    query = parsed.query
 
-    connect_kwargs = {'database': path_parts[0]}
+    connect_kwargs = {'database': path}
     if parsed.username:
         connect_kwargs['user'] = parsed.username
     if parsed.password:
